@@ -11,7 +11,6 @@
 #include <librsvg/rsvg-cairo.h>
 #endif
 
-#include "eog-config-keys.h"
 #include "eog-marshal.h"
 #include "eog-scroll-view.h"
 #include "eog-debug.h"
@@ -75,10 +74,7 @@ static GtkTargetEntry target_table[] = {
 
 enum {
 	PROP_0,
-	PROP_BACKGROUND_COLOR,
-	PROP_SCROLLWHEEL_ZOOM,
-	PROP_USE_BG_COLOR,
-	PROP_ZOOM_MULTIPLIER
+	PROP_BACKGROUND_COLOR
 };
 
 /* Private part of the EogScrollView structure */
@@ -147,7 +143,6 @@ struct _EogScrollViewPrivate {
 	/* the type of the cursor we are currently showing */
 	EogScrollViewCursor cursor;
 
-	gboolean  use_bg_color;
 	GdkColor *background_color;
 	GdkColor *override_bg_color;
 
@@ -2186,55 +2181,13 @@ eog_scroll_view_scrollbars_visible (EogScrollView *view)
     object creation/freeing
   ---------------------------------*/
 
-static gboolean
-sv_string_to_color_mapping (GValue   *value,
-			    GVariant *variant,
-			    gpointer  user_data)
-{
-	GdkColor color;
-
-	g_return_val_if_fail (g_variant_is_of_type (variant, G_VARIANT_TYPE_STRING), FALSE);
-
-	if (gdk_color_parse (g_variant_get_string (variant, NULL), &color)) {
-		g_value_set_boxed (value, &color);
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
-static GVariant*
-sv_color_to_string_mapping (const GValue       *value,
-			    const GVariantType *expected_type,
-			    gpointer            user_data)
-{
-	GVariant *variant = NULL;
-	GdkColor *color;
-	gchar *hex_val;
-
-	g_return_val_if_fail (G_VALUE_TYPE (value) == GDK_TYPE_COLOR, NULL);
-	g_return_val_if_fail (g_variant_type_equal (expected_type, G_VARIANT_TYPE_STRING), NULL);
-
-	color = g_value_get_boxed (value);
-	hex_val = g_strdup_printf ("#%02X%02X%02X",
-				   color->red / 256,
-				   color->green / 256,
-				   color->blue / 256);
-	variant = g_variant_new_string (hex_val);
-	g_free (hex_val);
-
-	return variant;
-}
-
 
 static void
 eog_scroll_view_init (EogScrollView *view)
 {
-	GSettings *settings;
 	EogScrollViewPrivate *priv;
 
 	priv = view->priv = EOG_SCROLL_VIEW_GET_PRIVATE (view);
-	settings = g_settings_new (EOG_CONF_VIEW);
 
 	priv->zoom = 1.0;
 	priv->min_zoom = MIN_ZOOM_FACTOR;
@@ -2252,16 +2205,7 @@ eog_scroll_view_init (EogScrollView *view)
 	priv->transp_color = 0;
 	priv->cursor = EOG_SCROLL_VIEW_CURSOR_NORMAL;
 	priv->menu = NULL;
-	
-	g_settings_bind (settings, EOG_CONF_VIEW_USE_BG_COLOR, view,
-			 "use-background-color", G_SETTINGS_BIND_DEFAULT);
-	g_settings_bind_with_mapping (settings, EOG_CONF_VIEW_BACKGROUND_COLOR,
-				      view, "background-color",
-				      G_SETTINGS_BIND_DEFAULT,
-				      sv_string_to_color_mapping,
-				      sv_color_to_string_mapping, NULL, NULL);
-	g_object_unref (settings);
-
+	priv->background_color = NULL;
 	priv->override_bg_color = NULL;
 	priv->background_surface = NULL;
 }
@@ -2320,19 +2264,10 @@ eog_scroll_view_get_property (GObject *object, guint property_id,
 	priv = view->priv;
 
 	switch (property_id) {
-	case PROP_USE_BG_COLOR:
-		g_value_set_boolean (value, priv->use_bg_color);
-		break;
 	case PROP_BACKGROUND_COLOR:
 		//FIXME: This doesn't really handle the NULL color.
 		g_value_set_boxed (value, priv->background_color);
 		break;
-	case PROP_SCROLLWHEEL_ZOOM:
-		g_value_set_boolean (value, priv->scroll_wheel_zoom);
-		break;
-	case PROP_ZOOM_MULTIPLIER:
-		g_value_set_double (value, priv->zoom_multiplier);
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 	}
@@ -2351,21 +2286,12 @@ eog_scroll_view_set_property (GObject *object, guint property_id,
 	priv = view->priv;
 
 	switch (property_id) {
-	case PROP_USE_BG_COLOR:
-		eog_scroll_view_set_use_bg_color (view, g_value_get_boolean (value));
-		break;
 	case PROP_BACKGROUND_COLOR:
 	{
 		const GdkColor *color = g_value_get_boxed (value);
 		eog_scroll_view_set_background_color (view, color);
 		break;
 	}
-	case PROP_SCROLLWHEEL_ZOOM:
-		eog_scroll_view_set_scroll_wheel_zoom (view, g_value_get_boolean (value));
-		break;
-	case PROP_ZOOM_MULTIPLIER:
-		eog_scroll_view_set_zoom_multiplier (view, g_value_get_double (value));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 	}
@@ -2398,34 +2324,6 @@ eog_scroll_view_class_init (EogScrollViewClass *klass)
 				    GDK_TYPE_COLOR,
 				    G_PARAM_READWRITE | G_PARAM_STATIC_NAME));
 
-	g_object_class_install_property (
-		gobject_class, PROP_USE_BG_COLOR,
-		g_param_spec_boolean ("use-background-color", NULL, NULL, FALSE,
-				      G_PARAM_READWRITE | G_PARAM_STATIC_NAME));
-
-	/**
-	 * EogScrollView:zoom-multiplier:
-	 *
-	 * The current zoom factor is multiplied with this value + 1.0 when
-	 * scrolling with the scrollwheel to determine the next zoom factor.
-	 */
-	g_object_class_install_property (
-		gobject_class, PROP_ZOOM_MULTIPLIER,
-		g_param_spec_double ("zoom-multiplier", NULL, NULL,
-				     -G_MAXDOUBLE, G_MAXDOUBLE - 1.0, 0.05,
-				     G_PARAM_READWRITE | G_PARAM_STATIC_NAME));
-
-	/**
-	 * EogScrollView:scrollwheel-zoom:
-	 *
-	 * If %TRUE the scrollwheel will zoom the view, otherwise it will be
-	 * used for scrolling a zoomed image.
-	 */
-	g_object_class_install_property (
-		gobject_class, PROP_SCROLLWHEEL_ZOOM,
-		g_param_spec_boolean ("scrollwheel-zoom", NULL, NULL, TRUE,
-				      G_PARAM_READWRITE | G_PARAM_STATIC_NAME));
-
 	view_signals [SIGNAL_ZOOM_CHANGED] =
 		g_signal_new ("zoom_changed",
 			      EOG_TYPE_SCROLL_VIEW,
@@ -2658,12 +2556,8 @@ _eog_scroll_view_update_bg_color (EogScrollView *view)
 	const GdkColor *selected;
 	EogScrollViewPrivate *priv = view->priv;
 
-	if (!priv->use_bg_color)
-		selected = NULL;
-	else if (priv->override_bg_color)
-		selected = priv->override_bg_color;
-	else
-		selected = priv->background_color;
+	selected = (priv->override_bg_color) ? priv->override_bg_color
+					     : priv->background_color;
 
 	if (priv->transp_style == EOG_TRANSP_BACKGROUND
 	    && priv->background_surface != NULL) {
@@ -2698,34 +2592,13 @@ eog_scroll_view_override_bg_color (EogScrollView *view,
 		_eog_scroll_view_update_bg_color (view);
 }
 
-void
-eog_scroll_view_set_use_bg_color (EogScrollView *view, gboolean use)
-{
-	EogScrollViewPrivate *priv;
-
-	g_return_if_fail (EOG_IS_SCROLL_VIEW (view));
-
-	priv = view->priv;
-
-	if (use != priv->use_bg_color) {
-		priv->use_bg_color = use;
-
-		_eog_scroll_view_update_bg_color (view);
-
-		g_object_notify (G_OBJECT (view), "use-background-color");
-	}
-}
-
 void
 eog_scroll_view_set_scroll_wheel_zoom (EogScrollView *view,
 				       gboolean       scroll_wheel_zoom)
 {
 	g_return_if_fail (EOG_IS_SCROLL_VIEW (view));
 
-	if (view->priv->scroll_wheel_zoom != scroll_wheel_zoom) {
-	        view->priv->scroll_wheel_zoom = scroll_wheel_zoom;
-		g_object_notify (G_OBJECT (view), "scrollwheel-zoom");
-	}
+        view->priv->scroll_wheel_zoom = scroll_wheel_zoom;
 }
 
 void
@@ -2735,6 +2608,4 @@ eog_scroll_view_set_zoom_multiplier (EogScrollView *view,
 	g_return_if_fail (EOG_IS_SCROLL_VIEW (view));
 
         view->priv->zoom_multiplier = 1.0 + zoom_multiplier;
-
-	g_object_notify (G_OBJECT (view), "zoom-multiplier");
 }
